@@ -238,7 +238,9 @@ class MinkowskiConvolutionBase(MinkowskiModuleBase):
 
         """
         super(MinkowskiConvolutionBase, self).__init__()
-        assert dimension > 0, f"dimension must be a positive integer, {dimension}"
+        assert (
+            dimension > 0
+        ), f"Invalid dimension. Please provide a valid dimension argument. dimension={dimension}"
 
         if kernel_generator is None:
             kernel_generator = KernelGenerator(
@@ -338,11 +340,14 @@ class MinkowskiConvolutionBase(MinkowskiModuleBase):
                 self.bias.data.uniform_(-stdv, stdv)
 
     def __repr__(self):
-        s = "(in={}, out={}, region_type={}, ".format(
-            self.in_channels, self.out_channels, self.kernel_generator.region_type
+        s = "(in={}, out={}, ".format(
+            self.in_channels,
+            self.out_channels,
         )
         if self.kernel_generator.region_type in [RegionType.CUSTOM]:
-            s += "kernel_volume={}, ".format(self.kernel_generator.kernel_volume)
+            s += "region_type={}, kernel_volume={}, ".format(
+                self.kernel_generator.region_type, self.kernel_generator.kernel_volume
+            )
         else:
             s += "kernel_size={}, ".format(self.kernel_generator.kernel_size)
         s += "stride={}, dilation={})".format(
