@@ -391,9 +391,11 @@ CoordinateMapManager<coordinate_type, coordinate_field_type, TemplatedAllocator,
                                      TemplatedAllocator, CoordinateMapType>()(
           map_key, coordinate, *this);
 
+  LOG_DEBUG("map_inverse_map initialized");
   py::object py_key = py::cast(new CoordinateMapKey(coordinate_size, map_key));
+  LOG_DEBUG("py key initialized");
 
-  return std::make_pair(py_key, std::move(map_inverse_map));
+  return std::make_pair(py_key, map_inverse_map);
 }
 
 // stride
@@ -500,6 +502,7 @@ CoordinateMapManager<coordinate_type, coordinate_field_type, TemplatedAllocator,
     }
   }
 
+  LOG_DEBUG("return origin()");
   // (key, new map generated flag)
   return std::make_pair(origin_map_key, !exists_origin_map);
 }
@@ -596,8 +599,8 @@ struct stride_map_functor<coordinate_type, std::allocator, CoordinateMapCPU,
   cpu_kernel_map
   operator()(CoordinateMapCPU<coordinate_type, std::allocator> const &in_map,
              CoordinateMapCPU<coordinate_type, std::allocator> const &out_map,
-             default_types::stride_type const &stride) {
-    return in_map.stride_map(out_map, stride);
+             default_types::stride_type const &out_tensor_stride) {
+    return in_map.stride_map(out_map, out_tensor_stride);
   }
 };
 
@@ -777,7 +780,7 @@ CoordinateMapManager<
           auto const stride_map =
               detail::stride_map_functor<coordinate_type, TemplatedAllocator,
                                          CoordinateMapType, kernel_map_type>()(
-                  out_map, in_map, kernel_stride);
+                  out_map, in_map, in_map.get_tensor_stride());
 
           // TODO Replace the kernel_map values to shared pointers.
           m_kernel_maps[kernel_map_key] =
@@ -1018,7 +1021,7 @@ CoordinateMapManager<coordinate_type, coordinate_field_type, TemplatedAllocator,
     auto const stride_map =
         detail::stride_map_functor<coordinate_type, TemplatedAllocator,
                                    CoordinateMapType, kernel_map_type>()(
-            in_map, strided_map, kernel_stride);
+            in_map, strided_map, strided_map.get_tensor_stride());
 
     m_kernel_maps[kernel_map_key] = std::move(stride_map);
   }
@@ -1327,6 +1330,7 @@ CoordinateMapManager<coordinate_type, coordinate_field_type, TemplatedAllocator,
   auto const &map = it->second;
   auto const nrows = map.size();
   auto const ncols = map.coordinate_size();
+  LOG_DEBUG("coordinate map nrows:", nrows, "ncols:", ncols);
 
   // CPU torch.IntTensor
   auto options = torch::TensorOptions().dtype(torch::kInt).requires_grad(false);
@@ -1340,8 +1344,10 @@ CoordinateMapManager<coordinate_type, coordinate_field_type, TemplatedAllocator,
   }
   at::Tensor coordinates = torch::empty({(long)nrows, (long)ncols}, options);
 
+  LOG_DEBUG("Initialized coordinates");
   // copy to the out coords
   map.copy_coordinates(coordinates.template data_ptr<coordinate_type>());
+  LOG_DEBUG("Copied coordinates");
   return coordinates;
 }
 
